%define ALD_Ver		1.2.4

Name:         m4

License:      GPL
Summary:      GNU m4 the traditional Unix macro processor.
Group:        Development/Compilers
Version:      1.4.16
Release:      4

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/Compiler

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define CrossDestDir	/Cross

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	/usr/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-%{_os}%{_gnu}
%define target_  %{nil}

%endif # !_CROSS || !TARGETBUILD_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
GNU m4 is an implementation of the traditional Unix macro
processor.  It is mostly SVR4 compatible, although it has some
extensions (for example, handling more than 9 positional parameters
to macros).  m4 also has built-in functions for including files,
running shell commands, doing arithmetic, etc.  Autoconf needs GNU
m4 for generating configure scripts, but not for running them.
#-------------------------------
%package info
Summary:      Info for %{name}
Group:        Documentation
%description info
Info for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=" "

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
LDFLAGS=`case $GCC_VER_STR in 4.[56789].*) echo -static-libgcc ;; esac`
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
OPT47=
%endif

CFLAGS="$OPTFLAGS $OPT47 -ffunction-sections -fdata-sections -fno-stack-protector -std=gnu99"
LDFLAGS="$LDFLAGS -Wl,--gc-sections"

%if %{_CROSS} && (%{_os} != "mingw")
export ac_cv_sys_stack_overflow_works="yes"
export gl_cv_sigaltstack_low_base=="yes"
export ac_cv_sys_xsi_stack_overflow_heuristic="no"
export gl_cv_func_realpath_works="yes"
export gl_cv_header_working_fcntl_h="yes"
export gl_cv_func_getopt_posix="yes"
export gl_cv_func_getopt_gnu="yes"
export ac_cv_func_lstat_dereferences_slashed_symlink="yes"
export ac_cv_func_malloc_0_nonnull="yes"
export gl_cv_func_memchr_works="yes"
export gl_cv_func_posix_spawn_works="yes"
export gl_cv_func_ungetc_works="yes"
export gl_cv_func_setenv_works="yes"
export gl_cv_func_dup2_works="yes"
export gl_cv_func_gettimeofday_clobber="no"
export gl_cv_func_working_mkstemp="yes"
export gl_cv_func_readlink_works="yes"
export gl_cv_func_re_compile_pattern_working="yes"
export gl_cv_func_rename_slash_dst_works="yes"
export gl_cv_func_rename_slash_src_works="yes"
export gl_cv_func_rename_link_works="yes"
export gl_cv_func_rename_dest_works="yes"
export gl_cv_func_rmdir_works="yes"
export gl_cv_func_signbit="yes"
export gl_cv_func_signbit_gcc="yes"
export gl_cv_func_stat_dir_slash="yes"
export gl_cv_func_link_works="yes"
export gl_cv_func_svid_putenv="yes"
export gl_cv_func_symlink_works="yes"
export gl_cv_func_unsetenv_works="yes"
export M4_cv_func_rename_open_file_works="yes"
%endif

%configure \
%if %{_CROSS}
	--build=%{_build} \
	--host=%{target} \
%endif
	--disable-rpath \
	&>FConfigure_log.txt

make &>FMake_log.txt


# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

cp AUTHORS README THANKS $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-3.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

rm -rf $RPM_BUILD_ROOT%{_infodir}/dir

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-info-$SE $DD/%{name}-info-$DE
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%files
%{_prefix}
%else  #!mingw

%files
%{_bindir}
%{_mandir}
%{docdir}

%files info
%{_infodir}

%endif #!mingw
